@@ -1,6 +1,6 @@
-package App::GitAutofixup;
+package App::Git::Autofixup;
 
-our $VERSION = 0.001000;
+our $VERSION = 0.001001;
 
 =head1 NAME
 
